package com.yunzhi.training.common;

import cn.hutool.json.JSONObject;
import cn.hutool.jwt.JWT;
import cn.hutool.jwt.JWTUtil;
import cn.hutool.jwt.JWTValidator;
import cn.hutool.jwt.signers.JWTSigner;
import cn.hutool.jwt.signers.JWTSignerUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Date;
import java.util.Map;

/**
 * JWTUtils
 * jwt 辅助类
 * https://github.com/jwtk/jjwt
 */
public class JWTUtils {
    private static final Logger log = LoggerFactory.getLogger(JWTUtils.class);

    // 过期时间 30 分钟
    public static final long EXPIRE_TIME = 30 * 60 * 24;

    // 私钥
    static final JWTSigner signer = JWTSignerUtil.hs512("Yansen is so handsome. He is a good man. Everyone like him !!!".getBytes());

    // 请求头
    public static final String AUTH_HEADER = "X-Authorization-JWT";

    /**
     * 生成 token, claims 里必须要有 userId
     * @param claims
     * @return
     */
    public static String encode(Map<String, Object> claims) {
        Date[] datePair = getDatePair();
        Date iat = datePair[0];
        Date exp = datePair[1];

        return JWT.create()
                .setIssuedAt(iat)
                .setExpiresAt(exp)
                .addPayloads(claims)
                .sign(signer);
    }

    public static JSONObject decode(String token) throws Exception {
        return JWTUtil.parseToken(token).getPayloads();
    }

    public static String refresh(String token) {
        try {
            JWT jwt = JWTUtil.parseToken(token);

            Object obj = jwt.getPayload("iat");
            if (null != obj) {
                Date dt = (Date) obj;
                long currentTime = System.currentTimeMillis() / 1000;
                int oneMinute = 60;
                if (currentTime - dt.getTime() < oneMinute) {
                    return token;
                }
            }

            Date[] datePair = getDatePair();
            Date iat = datePair[0];
            Date exp = datePair[1];
            jwt.setIssuedAt(iat).setExpiresAt(exp);

            return jwt.sign(signer);
        } catch (Exception e) {
            log.error("解析 JWT Token 失败: {}", e.getMessage());
        }
        return null;
    }

    public static void refresh(String jws, HttpServletResponse response) {
        if (!StringUtils.isEmpty(jws)) {
            String token =  refresh(jws);
            response.addHeader(AUTH_HEADER, token);
        }
    }

    public static String getToken(HttpServletRequest request) {
        return request.getHeader(AUTH_HEADER);
    }

    public static void verify(String token) throws Exception {
        JWTValidator.of(token).validateAlgorithm(signer);
    }

    private static Date[] getDatePair() {
        LocalDateTime now = LocalDateTime.now();
        Date iat = Date.from(now.atZone(ZoneId.systemDefault()).toInstant());
        Date exp = Date.from(now.plusSeconds(EXPIRE_TIME).atZone(ZoneId.systemDefault()).toInstant());
        return new Date[]{iat, exp};
    }
}
