package com.yunzhi.training.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.training.common.BaseController;
import com.yunzhi.training.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.training.service.ITaQuestionPersonService;
import com.yunzhi.training.entity.TaQuestionPerson;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 答卷明细 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-02-18
 */

@Api(tags = "答卷明细")
@RestController
@RequestMapping("/")
public class TaQuestionPersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaQuestionPersonController.class);

    @Autowired
    public ITaQuestionPersonService iTaQuestionPersonService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taQuestionPerson",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taQuestionPersonList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaQuestionPerson> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaQuestionPerson> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaQuestionPerson> result = iTaQuestionPersonService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taQuestionPerson 实体对象
     * @return
     */
    @RequestMapping(value="/taQuestionPerson",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taQuestionPersonAdd(@ApiParam("保存内容") @RequestBody TaQuestionPerson taQuestionPerson) throws Exception{

        if (iTaQuestionPersonService.save(taQuestionPerson)){
            return ResponseBean.success(taQuestionPerson);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taQuestionPerson/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taQuestionPersonDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaQuestionPersonService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taQuestionPerson 实体对象
     * @return
     */
    @RequestMapping(value="/taQuestionPerson/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taQuestionPersonUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TaQuestionPerson taQuestionPerson) throws Exception{

        if (iTaQuestionPersonService.updateById(taQuestionPerson)){
            return ResponseBean.success(iTaQuestionPersonService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taQuestionPerson/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taQuestionPersonGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaQuestionPersonService.getById(id));
    }
}
